conf change: sensors: read and write path rename

Rename the readpath and writepath for camelcase styling to make all
configuration variables consistent.

Change-Id: I33f475075c8f40cd2029a5c0bfda950846cd5d44
Signed-off-by: Patrick Venture <venture@google.com>
diff --git a/conf.hpp b/conf.hpp
index c5734cc..cfea278 100644
--- a/conf.hpp
+++ b/conf.hpp
@@ -12,11 +12,11 @@
  */
 struct SensorConfig
 {
     /* Used for listen if readpath is passive. */
     std::string type;
     /* Can be a sensor path or a dbus path. */
-    std::string readpath;
-    std::string writepath;
+    std::string readPath;
+    std::string writePath;
     /* min/max values for writing a percentage or error checking. */
     int64_t min;
     int64_t max;
@@ -12,11 +12,11 @@
 struct SensorConfig
 {
-    /* Used for listen if readpath is passive. */
+    /* Used for listen if readPath is passive. */
     std::string type;
     /* Can be a sensor path or a dbus path. */